==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgsBuilder internal
constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("batapngrmaglxywh")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("soahkmikiarnqfub")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("eynmixenmpulyvsl")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("dsgdefhpffsyhddt")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("uvojuvgcspitosjd")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs =
        ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("mfxvbwyqxtleqwes")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("gyqeaxdbxlnmllja")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("lldmgsjydrkerdik")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("kmfutxvdcxukdkva")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("ofbyfueewcvbmreu")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs =
        ResponseHeadersPolicyCorsConfigAccessControlAllowOriginsArgs(
            items = items,
        )
}
